summaryrefslogtreecommitdiffstats
path: root/tdeui/kxmlguiclient.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeui/kxmlguiclient.h')
-rw-r--r--tdeui/kxmlguiclient.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdeui/kxmlguiclient.h b/tdeui/kxmlguiclient.h
index c05a1afd8..78c412602 100644
--- a/tdeui/kxmlguiclient.h
+++ b/tdeui/kxmlguiclient.h
@@ -29,7 +29,7 @@
class TQWidget;
class KAction;
class KActionCollection;
-class KInstance;
+class TDEInstance;
class KXMLGUIClientPrivate;
class KXMLGUIFactory;
class KXMLGUIBuilder;
@@ -95,9 +95,9 @@ public:
virtual KActionCollection* actionCollection() const;
/**
* @return The instance ( KInstance ) for this GUI client.
*/
- virtual KInstance *instance() const;
+ virtual TDEInstance *instance() const;
/**
* @return The parsed XML in a TQDomDocument, set by
@@ -271,12 +271,12 @@ protected:
//bool addSuperClient( KXMLGUIClient * );
/**
* Sets the instance ( KInstance) for this part.
*
* Call this first in the inherited class constructor.
* (At least before setXMLFile().)
*/
- virtual void setInstance( KInstance *instance );
+ virtual void setInstance( TDEInstance *instance );
/**
* Sets the name of the rc file containing the XML for the part.
@@ -95,9 +95,9 @@ public:
virtual KActionCollection* actionCollection() const;
/**
- * @return The instance ( KInstance ) for this GUI client.
+ * @return The instance ( TDEInstance ) for this GUI client.
*/
@@ -271,12 +271,12 @@ protected:
//bool addSuperClient( KXMLGUIClient * );
/**
- * Sets the instance ( KInstance) for this part.
+ * Sets the instance ( TDEInstance) for this part.
*
* Call this first in the inherited class constructor.